==> cherokee-0.4.0-beta1.tar.gz: cherokee-0.4.0/src/plugin_table.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2002 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE2_PLUGIN_TABLE_H__
#define __CHEROKEE2_PLUGIN_TABLE_H__

#include "common.h"
#include "table.h"

typedef struct {
	   cherokee_table_t table;
	   cherokee_table_t handlers;
} cherokee_plugin_table_t;

#define PTABLE(x) ((cherokee_plugin_table_t *)(x))


ret_t cherokee_plugin_table_new           (cherokee_plugin_table_t **pt);
ret_t cherokee_plugin_table_free          (cherokee_plugin_table_t  *pt);

ret_t cherokee_plugin_table_set           (cherokee_plugin_table_t  *pt, char *dir, char *handler);
void* cherokee_plugin_table_get_from_url  (cherokee_plugin_table_t  *pt, char *url);

#endif /* __CHEROKEE2_PLUGIN_TABLE_H__ */

==> cherokee-0.4.2-beta1.tar.gz: cherokee-0.4.2/src/plugin_table.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2002 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE2_PLUGIN_TABLE_H__
#define __CHEROKEE2_PLUGIN_TABLE_H__

#include "common.h"
#include "table.h"
#include "plugin_table_entry.h"

typedef struct {
	   cherokee_table_t table;
	   cherokee_table_t handlers;
} cherokee_plugin_table_t;

#define PTABLE(x) ((cherokee_plugin_table_t *)(x))

ret_t cherokee_plugin_table_new  (cherokee_plugin_table_t **pt);
ret_t cherokee_plugin_table_free (cherokee_plugin_table_t  *pt);

ret_t cherokee_plugin_table_set  (cherokee_plugin_table_t  *pt, char *dir, char *handler_name, cherokee_plugin_table_entry_t *plugin_entry);
ret_t cherokee_plugin_table_get  (cherokee_plugin_table_t  *pt, char *requested_url, cherokee_plugin_table_entry_t **plugin_entry, char **web_dir);


#endif /* __CHEROKEE2_PLUGIN_TABLE_H__ */
